Module Name: src
Committed By: skrll
Date: Tue Feb 1 18:33:25 UTC 2011
Modified Files:
src/sys/arch/hp700/dev: apic.c asp.c cpu.c dino.c lasi.c mongoose.c
siop_sgc.c wax.c
src/sys/arch/hp700/gsc: com_gsc.c gscbus.c gscbusvar.h gsckbc.c
harmony.c if_ie_gsc.c if_iee_gsc.c lpt_gsc.c oosiop_gsc.c
osiop_gsc.c siop_gsc.c
src/sys/arch/hp700/hp700: genassym.cf intr.c intr.h locore.S
Log Message:
Change some structure and structure member names to better suit my eye.
No functional change.
Same code before and after.
To generate a diff of this commit:
cvs rdiff -u -r1.10 -r1.11 src/sys/arch/hp700/dev/apic.c
cvs rdiff -u -r1.17 -r1.18 src/sys/arch/hp700/dev/asp.c
cvs rdiff -u -r1.18 -r1.19 src/sys/arch/hp700/dev/cpu.c
cvs rdiff -u -r1.28 -r1.29 src/sys/arch/hp700/dev/dino.c
cvs rdiff -u -r1.19 -r1.20 src/sys/arch/hp700/dev/lasi.c
cvs rdiff -u -r1.20 -r1.21 src/sys/arch/hp700/dev/mongoose.c
cvs rdiff -u -r1.6 -r1.7 src/sys/arch/hp700/dev/siop_sgc.c
cvs rdiff -u -r1.16 -r1.17 src/sys/arch/hp700/dev/wax.c
cvs rdiff -u -r1.15 -r1.16 src/sys/arch/hp700/gsc/com_gsc.c
cvs rdiff -u -r1.21 -r1.22 src/sys/arch/hp700/gsc/gscbus.c
cvs rdiff -u -r1.9 -r1.10 src/sys/arch/hp700/gsc/gscbusvar.h
cvs rdiff -u -r1.6 -r1.7 src/sys/arch/hp700/gsc/gsckbc.c
cvs rdiff -u -r1.18 -r1.19 src/sys/arch/hp700/gsc/harmony.c \
src/sys/arch/hp700/gsc/if_iee_gsc.c src/sys/arch/hp700/gsc/osiop_gsc.c
cvs rdiff -u -r1.22 -r1.23 src/sys/arch/hp700/gsc/if_ie_gsc.c
cvs rdiff -u -r1.12 -r1.13 src/sys/arch/hp700/gsc/lpt_gsc.c \
src/sys/arch/hp700/gsc/siop_gsc.c
cvs rdiff -u -r1.11 -r1.12 src/sys/arch/hp700/gsc/oosiop_gsc.c
cvs rdiff -u -r1.31 -r1.32 src/sys/arch/hp700/hp700/genassym.cf
cvs rdiff -u -r1.33 -r1.34 src/sys/arch/hp700/hp700/intr.c
cvs rdiff -u -r1.14 -r1.15 src/sys/arch/hp700/hp700/intr.h
cvs rdiff -u -r1.53 -r1.54 src/sys/arch/hp700/hp700/locore.S
Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.
Modified files:
Index: src/sys/arch/hp700/dev/apic.c
diff -u src/sys/arch/hp700/dev/apic.c:1.10 src/sys/arch/hp700/dev/apic.c:1.11
--- src/sys/arch/hp700/dev/apic.c:1.10 Thu Jan 27 13:57:39 2011
+++ src/sys/arch/hp700/dev/apic.c Tue Feb 1 18:33:24 2011
@@ -1,4 +1,4 @@
-/* $NetBSD: apic.c,v 1.10 2011/01/27 13:57:39 skrll Exp $ */
+/* $NetBSD: apic.c,v 1.11 2011/02/01 18:33:24 skrll Exp $ */
/* $OpenBSD: apic.c,v 1.7 2007/10/06 23:50:54 krw Exp $ */
@@ -139,7 +139,7 @@
#endif
line = PCI_INTERRUPT_LINE(reg);
if (sc->sc_irq[line] == 0)
- sc->sc_irq[line] = hp700_intr_allocate_bit(&int_reg_cpu);
+ sc->sc_irq[line] = hp700_intr_allocate_bit(&ir_cpu);
*ihp = (line << APIC_INT_LINE_SHIFT) | sc->sc_irq[line];
return (APIC_INT_IRQ(*ihp) == 0);
}
@@ -203,7 +203,7 @@
return arg;
}
- iv = hp700_intr_establish(pri, apic_intr, aiv, &int_reg_cpu, irq);
+ iv = hp700_intr_establish(pri, apic_intr, aiv, &ir_cpu, irq);
if (iv) {
ent0 = (31 - irq) & APIC_ENT0_VEC;
ent0 |= apic_get_int_ent0(sc, line);
Index: src/sys/arch/hp700/dev/asp.c
diff -u src/sys/arch/hp700/dev/asp.c:1.17 src/sys/arch/hp700/dev/asp.c:1.18
--- src/sys/arch/hp700/dev/asp.c:1.17 Sat Dec 11 19:32:05 2010
+++ src/sys/arch/hp700/dev/asp.c Tue Feb 1 18:33:24 2011
@@ -1,4 +1,4 @@
-/* $NetBSD: asp.c,v 1.17 2010/12/11 19:32:05 skrll Exp $ */
+/* $NetBSD: asp.c,v 1.18 2011/02/01 18:33:24 skrll Exp $ */
/* $OpenBSD: asp.c,v 1.5 2000/02/09 05:04:22 mickey Exp $ */
@@ -37,7 +37,7 @@
*/
#include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: asp.c,v 1.17 2010/12/11 19:32:05 skrll Exp $");
+__KERNEL_RCSID(0, "$NetBSD: asp.c,v 1.18 2011/02/01 18:33:24 skrll Exp $");
#include <sys/param.h>
#include <sys/systm.h>
@@ -125,7 +125,7 @@
struct asp_softc {
device_t sc_dev;
- struct hp700_int_reg sc_int_reg;
+ struct hp700_interrupt_register sc_ir;
volatile struct asp_hwr *sc_hw;
volatile struct asp_trs *sc_trs;
@@ -174,7 +174,7 @@
/* Make sure we have an IRQ. */
if (ca->ca_irq == HP700CF_IRQ_UNDEF)
- ca->ca_irq = hp700_intr_allocate_bit(&int_reg_cpu);
+ ca->ca_irq = hp700_intr_allocate_bit(&ir_cpu);
/*
* Forcibly mask the HPA down to the start of the ASP
@@ -251,10 +251,10 @@
sc->sc_trs->asp_lan, sc->sc_trs->asp_scsi);
/* Establish the interrupt register. */
- hp700_intr_reg_establish(&sc->sc_int_reg);
- sc->sc_int_reg.int_reg_name = device_xname(self);
- sc->sc_int_reg.int_reg_mask = &sc->sc_trs->asp_imr;
- sc->sc_int_reg.int_reg_req = &sc->sc_trs->asp_irr;
+ hp700_interrupt_register_establish(&sc->sc_ir);
+ sc->sc_ir.ir_name = device_xname(self);
+ sc->sc_ir.ir_mask = &sc->sc_trs->asp_imr;
+ sc->sc_ir.ir_req = &sc->sc_trs->asp_irr;
/* Attach the GSC bus. */
ga.ga_ca = *ca; /* clone from us */
@@ -269,7 +269,7 @@
}
ga.ga_name = "gsc";
- ga.ga_int_reg = &sc->sc_int_reg;
+ ga.ga_ir = &sc->sc_ir;
ga.ga_fix_args = asp_fix_args;
ga.ga_fix_args_cookie = sc;
ga.ga_scsi_target = sc->sc_trs->asp_scsi;
Index: src/sys/arch/hp700/dev/cpu.c
diff -u src/sys/arch/hp700/dev/cpu.c:1.18 src/sys/arch/hp700/dev/cpu.c:1.19
--- src/sys/arch/hp700/dev/cpu.c:1.18 Mon Jan 31 14:11:02 2011
+++ src/sys/arch/hp700/dev/cpu.c Tue Feb 1 18:33:24 2011
@@ -1,4 +1,4 @@
-/* $NetBSD: cpu.c,v 1.18 2011/01/31 14:11:02 skrll Exp $ */
+/* $NetBSD: cpu.c,v 1.19 2011/02/01 18:33:24 skrll Exp $ */
/* $OpenBSD: cpu.c,v 1.29 2009/02/08 18:33:28 miod Exp $ */
@@ -29,7 +29,7 @@
*/
#include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: cpu.c,v 1.18 2011/01/31 14:11:02 skrll Exp $");
+__KERNEL_RCSID(0, "$NetBSD: cpu.c,v 1.19 2011/02/01 18:33:24 skrll Exp $");
#include "opt_multiprocessor.h"
@@ -175,7 +175,7 @@
}
sc->sc_ih = hp700_intr_establish(IPL_CLOCK, clock_intr,
- NULL /*clockframe*/, &int_reg_cpu, 31);
+ NULL /*clockframe*/, &ir_cpu, 31);
#ifdef MULTIPROCESSOR
@@ -214,7 +214,7 @@
* ASP doesn't seem to like to use interrupt bits above 28
* or below 27.
*/
- int_reg_cpu.int_reg_allocatable_bits =
+ ir_cpu.ir_bits =
(1 << 28) | (1 << 27) | (1 << 26);
}
Index: src/sys/arch/hp700/dev/dino.c
diff -u src/sys/arch/hp700/dev/dino.c:1.28 src/sys/arch/hp700/dev/dino.c:1.29
--- src/sys/arch/hp700/dev/dino.c:1.28 Thu Jan 13 21:15:13 2011
+++ src/sys/arch/hp700/dev/dino.c Tue Feb 1 18:33:24 2011
@@ -1,4 +1,4 @@
-/* $NetBSD: dino.c,v 1.28 2011/01/13 21:15:13 skrll Exp $ */
+/* $NetBSD: dino.c,v 1.29 2011/02/01 18:33:24 skrll Exp $ */
/* $OpenBSD: dino.c,v 1.5 2004/02/13 20:39:31 mickey Exp $ */
@@ -29,7 +29,7 @@
*/
#include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: dino.c,v 1.28 2011/01/13 21:15:13 skrll Exp $");
+__KERNEL_RCSID(0, "$NetBSD: dino.c,v 1.29 2011/02/01 18:33:24 skrll Exp $");
/* #include "cardbus.h" */
@@ -118,7 +118,7 @@
int sc_ver;
void *sc_ih;
- struct hp700_int_reg sc_int_reg;
+ struct hp700_interrupt_register sc_ir;
bus_space_tag_t sc_bt;
bus_space_handle_t sc_bh;
bus_dma_tag_t sc_dmat;
@@ -406,7 +406,7 @@
{
struct dino_softc *sc = v;
- return hp700_intr_establish(pri, handler, arg, &sc->sc_int_reg, ih);
+ return hp700_intr_establish(pri, handler, arg, &sc->sc_ir, ih);
}
void
@@ -1596,7 +1596,7 @@
/* Make sure we have an IRQ. */
if (ca->ca_irq == HP700CF_IRQ_UNDEF)
- ca->ca_irq = hp700_intr_allocate_bit(&int_reg_cpu);
+ ca->ca_irq = hp700_intr_allocate_bit(&ir_cpu);
return 1;
}
@@ -1658,15 +1658,16 @@
r->iar0 = cpu_gethpa(0) | (31 - ca->ca_irq);
splx(s);
/* Establish the interrupt register. */
- hp700_intr_reg_establish(&sc->sc_int_reg);
- sc->sc_int_reg.int_reg_name = device_xname(self);
- sc->sc_int_reg.int_reg_mask = &r->imr;
- sc->sc_int_reg.int_reg_req = &r->irr0;
- sc->sc_int_reg.int_reg_level = &r->ilr;
+ hp700_interrupt_register_establish(&sc->sc_ir);
+ sc->sc_ir.ir_name = device_xname(self);
+ sc->sc_ir.ir_mask = &r->imr;
+ sc->sc_ir.ir_req = &r->irr0;
+ sc->sc_ir.ir_level = &r->ilr;
/* Add the I/O interrupt register. */
- sc->sc_ih = hp700_intr_establish(IPL_NONE, NULL, &sc->sc_int_reg,
- &int_reg_cpu, ca->ca_irq);
+ sc->sc_ih = hp700_intr_establish(IPL_NONE, NULL, &sc->sc_ir,
+ &ir_cpu, ca->ca_irq);
+
/* TODO establish the bus error interrupt */
Index: src/sys/arch/hp700/dev/lasi.c
diff -u src/sys/arch/hp700/dev/lasi.c:1.19 src/sys/arch/hp700/dev/lasi.c:1.20
--- src/sys/arch/hp700/dev/lasi.c:1.19 Thu Jan 13 21:15:13 2011
+++ src/sys/arch/hp700/dev/lasi.c Tue Feb 1 18:33:24 2011
@@ -1,4 +1,4 @@
-/* $NetBSD: lasi.c,v 1.19 2011/01/13 21:15:13 skrll Exp $ */
+/* $NetBSD: lasi.c,v 1.20 2011/02/01 18:33:24 skrll Exp $ */
/* $OpenBSD: lasi.c,v 1.4 2001/06/09 03:57:19 mickey Exp $ */
@@ -29,7 +29,7 @@
*/
#include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: lasi.c,v 1.19 2011/01/13 21:15:13 skrll Exp $");
+__KERNEL_RCSID(0, "$NetBSD: lasi.c,v 1.20 2011/02/01 18:33:24 skrll Exp $");
#undef LASIDEBUG
@@ -71,7 +71,7 @@
struct lasi_softc {
device_t sc_dev;
- struct hp700_int_reg sc_int_reg;
+ struct hp700_interrupt_register sc_ir;
struct lasi_hwr volatile *sc_hw;
struct lasi_trs volatile *sc_trs;
@@ -134,7 +134,7 @@
/* Make sure we have an IRQ. */
if (ca->ca_irq == HP700CF_IRQ_UNDEF)
- ca->ca_irq = hp700_intr_allocate_bit(&int_reg_cpu);
+ ca->ca_irq = hp700_intr_allocate_bit(&ir_cpu);
/*
* Forcibly mask the HPA down to the start of the LASI
@@ -190,16 +190,16 @@
splx(s);
/* Establish the interrupt register. */
- hp700_intr_reg_establish(&sc->sc_int_reg);
- sc->sc_int_reg.int_reg_name = device_xname(self);
- sc->sc_int_reg.int_reg_mask = &sc->sc_trs->lasi_imr;
- sc->sc_int_reg.int_reg_req = &sc->sc_trs->lasi_irr;
+ hp700_interrupt_register_establish(&sc->sc_ir);
+ sc->sc_ir.ir_name = device_xname(self);
+ sc->sc_ir.ir_mask = &sc->sc_trs->lasi_imr;
+ sc->sc_ir.ir_req = &sc->sc_trs->lasi_irr;
/* Attach the GSC bus. */
ga.ga_ca = *ca; /* clone from us */
ga.ga_name = "gsc";
- ga.ga_int_reg = &sc->sc_int_reg;
+ ga.ga_ir = &sc->sc_ir;
ga.ga_fix_args = lasi_fix_args;
ga.ga_fix_args_cookie = sc;
ga.ga_scsi_target = 7; /* XXX */
Index: src/sys/arch/hp700/dev/mongoose.c
diff -u src/sys/arch/hp700/dev/mongoose.c:1.20 src/sys/arch/hp700/dev/mongoose.c:1.21
--- src/sys/arch/hp700/dev/mongoose.c:1.20 Sun Dec 5 12:19:09 2010
+++ src/sys/arch/hp700/dev/mongoose.c Tue Feb 1 18:33:24 2011
@@ -1,4 +1,4 @@
-/* $NetBSD: mongoose.c,v 1.20 2010/12/05 12:19:09 skrll Exp $ */
+/* $NetBSD: mongoose.c,v 1.21 2011/02/01 18:33:24 skrll Exp $ */
/* $OpenBSD: mongoose.c,v 1.19 2010/01/01 20:28:42 kettenis Exp $ */
@@ -29,7 +29,7 @@
*/
#include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: mongoose.c,v 1.20 2010/12/05 12:19:09 skrll Exp $");
+__KERNEL_RCSID(0, "$NetBSD: mongoose.c,v 1.21 2011/02/01 18:33:24 skrll Exp $");
#define MONGOOSE_DEBUG 9
@@ -709,6 +709,6 @@
#undef R
/* attach interrupt */
- sc->sc_ih = hp700_intr_establish(IPL_NONE, mg_intr, sc, &int_reg_cpu,
+ sc->sc_ih = hp700_intr_establish(IPL_NONE, mg_intr, sc, &ir_cpu,
ca->ca_irq);
}
Index: src/sys/arch/hp700/dev/siop_sgc.c
diff -u src/sys/arch/hp700/dev/siop_sgc.c:1.6 src/sys/arch/hp700/dev/siop_sgc.c:1.7
--- src/sys/arch/hp700/dev/siop_sgc.c:1.6 Sun Dec 5 12:19:09 2010
+++ src/sys/arch/hp700/dev/siop_sgc.c Tue Feb 1 18:33:24 2011
@@ -1,4 +1,4 @@
-/* $NetBSD: siop_sgc.c,v 1.6 2010/12/05 12:19:09 skrll Exp $ */
+/* $NetBSD: siop_sgc.c,v 1.7 2011/02/01 18:33:24 skrll Exp $ */
/* $OpenBSD: siop_sgc.c,v 1.1 2007/08/05 19:09:52 kettenis Exp $ */
@@ -19,7 +19,7 @@
*/
#include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: siop_sgc.c,v 1.6 2010/12/05 12:19:09 skrll Exp $");
+__KERNEL_RCSID(0, "$NetBSD: siop_sgc.c,v 1.7 2011/02/01 18:33:24 skrll Exp $");
#include <sys/param.h>
#include <sys/device.h>
@@ -77,7 +77,7 @@
/* Make sure we have an IRQ. */
if (ca->ca_irq == HP700CF_IRQ_UNDEF)
- ca->ca_irq = hp700_intr_allocate_bit(&int_reg_cpu);
+ ca->ca_irq = hp700_intr_allocate_bit(&ir_cpu);
return 1;
}
@@ -134,7 +134,7 @@
siop_attach(&sgc->sc_siop);
- (void)hp700_intr_establish(IPL_BIO, siop_intr, sc, &int_reg_cpu,
+ (void)hp700_intr_establish(IPL_BIO, siop_intr, sc, &ir_cpu,
ca->ca_irq);
}
Index: src/sys/arch/hp700/dev/wax.c
diff -u src/sys/arch/hp700/dev/wax.c:1.16 src/sys/arch/hp700/dev/wax.c:1.17
--- src/sys/arch/hp700/dev/wax.c:1.16 Sun Dec 5 12:19:09 2010
+++ src/sys/arch/hp700/dev/wax.c Tue Feb 1 18:33:24 2011
@@ -1,4 +1,4 @@
-/* $NetBSD: wax.c,v 1.16 2010/12/05 12:19:09 skrll Exp $ */
+/* $NetBSD: wax.c,v 1.17 2011/02/01 18:33:24 skrll Exp $ */
/* $OpenBSD: wax.c,v 1.1 1998/11/23 03:04:10 mickey Exp $ */
@@ -29,7 +29,7 @@
*/
#include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: wax.c,v 1.16 2010/12/05 12:19:09 skrll Exp $");
+__KERNEL_RCSID(0, "$NetBSD: wax.c,v 1.17 2011/02/01 18:33:24 skrll Exp $");
#include <sys/param.h>
#include <sys/systm.h>
@@ -56,7 +56,7 @@
struct wax_softc {
device_t sc_dv;
- struct hp700_int_reg sc_int_reg;
+ struct hp700_interrupt_register sc_ir;
struct wax_regs volatile *sc_regs;
};
@@ -103,7 +103,7 @@
/* Make sure we have an IRQ. */
if (ca->ca_irq == HP700CF_IRQ_UNDEF) {
- ca->ca_irq = hp700_intr_allocate_bit(&int_reg_cpu);
+ ca->ca_irq = hp700_intr_allocate_bit(&ir_cpu);
}
return 1;
@@ -148,10 +148,10 @@
splx(s);
/* Establish the interrupt register. */
- hp700_intr_reg_establish(&sc->sc_int_reg);
- sc->sc_int_reg.int_reg_name = device_xname(self);
- sc->sc_int_reg.int_reg_mask = &sc->sc_regs->wax_imr;
- sc->sc_int_reg.int_reg_req = &sc->sc_regs->wax_irr;
+ hp700_interrupt_register_establish(&sc->sc_ir);
+ sc->sc_ir.ir_name = device_xname(self);
+ sc->sc_ir.ir_mask = &sc->sc_regs->wax_imr;
+ sc->sc_ir.ir_req = &sc->sc_regs->wax_irr;
/* Attach the GSC bus. */
ga.ga_ca = *ca; /* clone from us */
@@ -166,7 +166,7 @@
}
ga.ga_name = "gsc";
- ga.ga_int_reg = &sc->sc_int_reg;
+ ga.ga_ir = &sc->sc_ir;
ga.ga_fix_args = wax_fix_args;
ga.ga_fix_args_cookie = sc;
ga.ga_scsi_target = 7; /* XXX */
Index: src/sys/arch/hp700/gsc/com_gsc.c
diff -u src/sys/arch/hp700/gsc/com_gsc.c:1.15 src/sys/arch/hp700/gsc/com_gsc.c:1.16
--- src/sys/arch/hp700/gsc/com_gsc.c:1.15 Sun Dec 5 12:19:09 2010
+++ src/sys/arch/hp700/gsc/com_gsc.c Tue Feb 1 18:33:24 2011
@@ -1,4 +1,4 @@
-/* $NetBSD: com_gsc.c,v 1.15 2010/12/05 12:19:09 skrll Exp $ */
+/* $NetBSD: com_gsc.c,v 1.16 2011/02/01 18:33:24 skrll Exp $ */
/* $OpenBSD: com_gsc.c,v 1.8 2000/03/13 14:39:59 mickey Exp $ */
@@ -29,7 +29,7 @@
*/
#include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: com_gsc.c,v 1.15 2010/12/05 12:19:09 skrll Exp $");
+__KERNEL_RCSID(0, "$NetBSD: com_gsc.c,v 1.16 2011/02/01 18:33:24 skrll Exp $");
#include "opt_kgdb.h"
@@ -138,7 +138,7 @@
COM_INIT_REGS(sc->sc_regs, iot, ioh, iobase);
com_attach_subr(sc);
- gsc->sc_ih = hp700_intr_establish(IPL_TTY, comintr, sc, ga->ga_int_reg,
+ gsc->sc_ih = hp700_intr_establish(IPL_TTY, comintr, sc, ga->ga_ir,
ga->ga_irq);
}
Index: src/sys/arch/hp700/gsc/gscbus.c
diff -u src/sys/arch/hp700/gsc/gscbus.c:1.21 src/sys/arch/hp700/gsc/gscbus.c:1.22
--- src/sys/arch/hp700/gsc/gscbus.c:1.21 Thu Jan 13 21:15:14 2011
+++ src/sys/arch/hp700/gsc/gscbus.c Tue Feb 1 18:33:24 2011
@@ -1,4 +1,4 @@
-/* $NetBSD: gscbus.c,v 1.21 2011/01/13 21:15:14 skrll Exp $ */
+/* $NetBSD: gscbus.c,v 1.22 2011/02/01 18:33:24 skrll Exp $ */
/* $OpenBSD: gscbus.c,v 1.13 2001/08/01 20:32:04 miod Exp $ */
@@ -68,7 +68,7 @@
*/
#include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: gscbus.c,v 1.21 2011/01/13 21:15:14 skrll Exp $");
+__KERNEL_RCSID(0, "$NetBSD: gscbus.c,v 1.22 2011/02/01 18:33:24 skrll Exp $");
#define GSCDEBUG
@@ -148,9 +148,9 @@
aprint_normal("\n");
/* Add the I/O subsystem's interrupt register. */
- ga->ga_int_reg->int_reg_name = device_xname(self);
- sc->sc_ih = hp700_intr_establish(IPL_NONE, NULL, ga->ga_int_reg,
- &int_reg_cpu, ga->ga_irq);
+ ga->ga_ir->ir_name = device_xname(self);
+ sc->sc_ih = hp700_intr_establish(IPL_NONE, NULL, ga->ga_ir,
+ &ir_cpu, ga->ga_irq);
ga->ga_ca.ca_nmodules = MAXMODBUS;
ga->ga_ca.ca_hpabase = 0;
Index: src/sys/arch/hp700/gsc/gscbusvar.h
diff -u src/sys/arch/hp700/gsc/gscbusvar.h:1.9 src/sys/arch/hp700/gsc/gscbusvar.h:1.10
--- src/sys/arch/hp700/gsc/gscbusvar.h:1.9 Tue Nov 3 05:07:25 2009
+++ src/sys/arch/hp700/gsc/gscbusvar.h Tue Feb 1 18:33:24 2011
@@ -1,4 +1,4 @@
-/* $NetBSD: gscbusvar.h,v 1.9 2009/11/03 05:07:25 snj Exp $ */
+/* $NetBSD: gscbusvar.h,v 1.10 2011/02/01 18:33:24 skrll Exp $ */
/* $OpenBSD: gscbusvar.h,v 1.3 1999/08/16 02:48:39 mickey Exp $ */
@@ -43,7 +43,7 @@
/*#define ga_pdc_iodc_read ga_ca.ca_pdc_iodc_read */
/* The interrupt register for this GSC bus. */
- struct hp700_int_reg *ga_int_reg;
+ struct hp700_interrupt_register *ga_ir;
/* This fixes a module's attach arguments. */
void (*ga_fix_args)(void *, struct gsc_attach_args *);
Index: src/sys/arch/hp700/gsc/gsckbc.c
diff -u src/sys/arch/hp700/gsc/gsckbc.c:1.6 src/sys/arch/hp700/gsc/gsckbc.c:1.7
--- src/sys/arch/hp700/gsc/gsckbc.c:1.6 Sun Dec 5 12:19:09 2010
+++ src/sys/arch/hp700/gsc/gsckbc.c Tue Feb 1 18:33:24 2011
@@ -1,4 +1,4 @@
-/* $NetBSD: gsckbc.c,v 1.6 2010/12/05 12:19:09 skrll Exp $ */
+/* $NetBSD: gsckbc.c,v 1.7 2011/02/01 18:33:24 skrll Exp $ */
/*
* Copyright (c) 2004 Jochen Kunz.
* All rights reserved.
@@ -33,7 +33,7 @@
*/
#include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: gsckbc.c,v 1.6 2010/12/05 12:19:09 skrll Exp $");
+__KERNEL_RCSID(0, "$NetBSD: gsckbc.c,v 1.7 2011/02/01 18:33:24 skrll Exp $");
/* autoconfig and device stuff */
#include <sys/param.h>
@@ -268,7 +268,7 @@
}
aprint_debug(" (master)");
sc->sc_ih = hp700_intr_establish(IPL_TTY, gsckbc_intr, sc,
- ga->ga_int_reg, ga->ga_irq);
+ ga->ga_ir, ga->ga_irq);
master_sc = sc;
} else {
if (master_sc == NULL) {
Index: src/sys/arch/hp700/gsc/harmony.c
diff -u src/sys/arch/hp700/gsc/harmony.c:1.18 src/sys/arch/hp700/gsc/harmony.c:1.19
--- src/sys/arch/hp700/gsc/harmony.c:1.18 Sun Dec 5 12:19:09 2010
+++ src/sys/arch/hp700/gsc/harmony.c Tue Feb 1 18:33:24 2011
@@ -1,4 +1,4 @@
-/* $NetBSD: harmony.c,v 1.18 2010/12/05 12:19:09 skrll Exp $ */
+/* $NetBSD: harmony.c,v 1.19 2011/02/01 18:33:24 skrll Exp $ */
/* $OpenBSD: harmony.c,v 1.23 2004/02/13 21:28:19 mickey Exp $ */
@@ -280,7 +280,7 @@
offsetof(struct harmony_empty, playback[0][0]),
PLAYBACK_EMPTYS * HARMONY_BUFSIZE, BUS_DMASYNC_PREWRITE);
- (void) hp700_intr_establish(IPL_AUDIO, harmony_intr, sc, ga->ga_int_reg,
+ (void) hp700_intr_establish(IPL_AUDIO, harmony_intr, sc, ga->ga_ir,
ga->ga_irq);
/* set defaults */
Index: src/sys/arch/hp700/gsc/if_iee_gsc.c
diff -u src/sys/arch/hp700/gsc/if_iee_gsc.c:1.18 src/sys/arch/hp700/gsc/if_iee_gsc.c:1.19
--- src/sys/arch/hp700/gsc/if_iee_gsc.c:1.18 Sun Dec 5 12:19:09 2010
+++ src/sys/arch/hp700/gsc/if_iee_gsc.c Tue Feb 1 18:33:24 2011
@@ -1,4 +1,4 @@
-/* $NetBSD: if_iee_gsc.c,v 1.18 2010/12/05 12:19:09 skrll Exp $ */
+/* $NetBSD: if_iee_gsc.c,v 1.19 2011/02/01 18:33:24 skrll Exp $ */
/*
* Copyright (c) 2003 Jochen Kunz.
@@ -34,7 +34,7 @@
*/
#include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: if_iee_gsc.c,v 1.18 2010/12/05 12:19:09 skrll Exp $");
+__KERNEL_RCSID(0, "$NetBSD: if_iee_gsc.c,v 1.19 2011/02/01 18:33:24 skrll Exp $");
/* autoconfig and device stuff */
#include <sys/param.h>
@@ -250,7 +250,7 @@
}
sc_gsc->sc_ih = hp700_intr_establish(IPL_NET, iee_intr, sc,
- ga->ga_int_reg, ga->ga_irq);
+ ga->ga_ir, ga->ga_irq);
sc->sc_iee_reset = iee_gsc_reset;
sc->sc_iee_cmd = iee_gsc_cmd;
Index: src/sys/arch/hp700/gsc/osiop_gsc.c
diff -u src/sys/arch/hp700/gsc/osiop_gsc.c:1.18 src/sys/arch/hp700/gsc/osiop_gsc.c:1.19
--- src/sys/arch/hp700/gsc/osiop_gsc.c:1.18 Tue Jan 4 10:42:33 2011
+++ src/sys/arch/hp700/gsc/osiop_gsc.c Tue Feb 1 18:33:24 2011
@@ -1,4 +1,4 @@
-/* $NetBSD: osiop_gsc.c,v 1.18 2011/01/04 10:42:33 skrll Exp $ */
+/* $NetBSD: osiop_gsc.c,v 1.19 2011/02/01 18:33:24 skrll Exp $ */
/*
* Copyright (c) 2001 Matt Fredette. All rights reserved.
@@ -80,7 +80,7 @@
*/
#include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: osiop_gsc.c,v 1.18 2011/01/04 10:42:33 skrll Exp $");
+__KERNEL_RCSID(0, "$NetBSD: osiop_gsc.c,v 1.19 2011/02/01 18:33:24 skrll Exp $");
#include <sys/param.h>
#include <sys/systm.h>
@@ -183,7 +183,7 @@
#endif /* OSIOP_DEBUG */
osiop_attach(sc);
- (void)hp700_intr_establish(IPL_BIO, osiop_gsc_intr, sc, ga->ga_int_reg,
+ (void)hp700_intr_establish(IPL_BIO, osiop_gsc_intr, sc, ga->ga_ir,
ga->ga_irq);
}
Index: src/sys/arch/hp700/gsc/if_ie_gsc.c
diff -u src/sys/arch/hp700/gsc/if_ie_gsc.c:1.22 src/sys/arch/hp700/gsc/if_ie_gsc.c:1.23
--- src/sys/arch/hp700/gsc/if_ie_gsc.c:1.22 Sun Dec 5 12:19:09 2010
+++ src/sys/arch/hp700/gsc/if_ie_gsc.c Tue Feb 1 18:33:24 2011
@@ -1,4 +1,4 @@
-/* $NetBSD: if_ie_gsc.c,v 1.22 2010/12/05 12:19:09 skrll Exp $ */
+/* $NetBSD: if_ie_gsc.c,v 1.23 2011/02/01 18:33:24 skrll Exp $ */
/* $OpenBSD: if_ie_gsc.c,v 1.6 2001/01/12 22:57:04 mickey Exp $ */
@@ -38,7 +38,7 @@
*/
#include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: if_ie_gsc.c,v 1.22 2010/12/05 12:19:09 skrll Exp $");
+__KERNEL_RCSID(0, "$NetBSD: if_ie_gsc.c,v 1.23 2011/02/01 18:33:24 skrll Exp $");
#include <sys/param.h>
#include <sys/systm.h>
@@ -559,5 +559,5 @@
"i82596DX",
myaddr, ie_gsc_media, IE_NMEDIA, ie_gsc_media[0]);
gsc->sc_ih = hp700_intr_establish(IPL_NET, i82586_intr, sc,
- ga->ga_int_reg, ga->ga_irq);
+ ga->ga_ir, ga->ga_irq);
}
Index: src/sys/arch/hp700/gsc/lpt_gsc.c
diff -u src/sys/arch/hp700/gsc/lpt_gsc.c:1.12 src/sys/arch/hp700/gsc/lpt_gsc.c:1.13
--- src/sys/arch/hp700/gsc/lpt_gsc.c:1.12 Sun Dec 5 12:19:09 2010
+++ src/sys/arch/hp700/gsc/lpt_gsc.c Tue Feb 1 18:33:24 2011
@@ -1,4 +1,4 @@
-/* $NetBSD: lpt_gsc.c,v 1.12 2010/12/05 12:19:09 skrll Exp $ */
+/* $NetBSD: lpt_gsc.c,v 1.13 2011/02/01 18:33:24 skrll Exp $ */
/* $OpenBSD: lpt_gsc.c,v 1.6 2000/07/21 17:41:06 mickey Exp $ */
@@ -53,7 +53,7 @@
*/
#include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: lpt_gsc.c,v 1.12 2010/12/05 12:19:09 skrll Exp $");
+__KERNEL_RCSID(0, "$NetBSD: lpt_gsc.c,v 1.13 2011/02/01 18:33:24 skrll Exp $");
#include <sys/param.h>
#include <sys/systm.h>
@@ -214,7 +214,7 @@
lpt_attach_subr(sc);
- sc->sc_ih = hp700_intr_establish(IPL_TTY, lptintr, sc, ga->ga_int_reg,
+ sc->sc_ih = hp700_intr_establish(IPL_TTY, lptintr, sc, ga->ga_ir,
ga->ga_irq);
aprint_normal("\n");
}
Index: src/sys/arch/hp700/gsc/siop_gsc.c
diff -u src/sys/arch/hp700/gsc/siop_gsc.c:1.12 src/sys/arch/hp700/gsc/siop_gsc.c:1.13
--- src/sys/arch/hp700/gsc/siop_gsc.c:1.12 Sun Dec 5 12:19:09 2010
+++ src/sys/arch/hp700/gsc/siop_gsc.c Tue Feb 1 18:33:24 2011
@@ -1,4 +1,4 @@
-/* $NetBSD: siop_gsc.c,v 1.12 2010/12/05 12:19:09 skrll Exp $ */
+/* $NetBSD: siop_gsc.c,v 1.13 2011/02/01 18:33:24 skrll Exp $ */
/* $OpenBSD: siop_gsc.c,v 1.4 2007/08/23 21:01:22 kettenis Exp $ */
@@ -19,7 +19,7 @@
*/
#include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: siop_gsc.c,v 1.12 2010/12/05 12:19:09 skrll Exp $");
+__KERNEL_RCSID(0, "$NetBSD: siop_gsc.c,v 1.13 2011/02/01 18:33:24 skrll Exp $");
#include <sys/param.h>
#include <sys/device.h>
@@ -124,7 +124,7 @@
siop_attach(sc);
- (void)hp700_intr_establish(IPL_BIO, siop_intr, sc, ga->ga_int_reg,
+ (void)hp700_intr_establish(IPL_BIO, siop_intr, sc, ga->ga_ir,
ga->ga_irq);
}
Index: src/sys/arch/hp700/gsc/oosiop_gsc.c
diff -u src/sys/arch/hp700/gsc/oosiop_gsc.c:1.11 src/sys/arch/hp700/gsc/oosiop_gsc.c:1.12
--- src/sys/arch/hp700/gsc/oosiop_gsc.c:1.11 Tue Jan 4 10:42:33 2011
+++ src/sys/arch/hp700/gsc/oosiop_gsc.c Tue Feb 1 18:33:24 2011
@@ -1,4 +1,4 @@
-/* $NetBSD: oosiop_gsc.c,v 1.11 2011/01/04 10:42:33 skrll Exp $ */
+/* $NetBSD: oosiop_gsc.c,v 1.12 2011/02/01 18:33:24 skrll Exp $ */
/*
* Copyright (c) 2001 Matt Fredette. All rights reserved.
@@ -80,7 +80,7 @@
*/
#include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: oosiop_gsc.c,v 1.11 2011/01/04 10:42:33 skrll Exp $");
+__KERNEL_RCSID(0, "$NetBSD: oosiop_gsc.c,v 1.12 2011/02/01 18:33:24 skrll Exp $");
#include <sys/param.h>
#include <sys/systm.h>
@@ -175,7 +175,7 @@
oosiop_attach(sc);
(void)hp700_intr_establish(IPL_BIO, oosiop_gsc_intr, sc,
- ga->ga_int_reg, ga->ga_irq);
+ ga->ga_ir, ga->ga_irq);
}
/*
Index: src/sys/arch/hp700/hp700/genassym.cf
diff -u src/sys/arch/hp700/hp700/genassym.cf:1.31 src/sys/arch/hp700/hp700/genassym.cf:1.32
--- src/sys/arch/hp700/hp700/genassym.cf:1.31 Sun Jan 23 21:53:39 2011
+++ src/sys/arch/hp700/hp700/genassym.cf Tue Feb 1 18:33:24 2011
@@ -1,4 +1,4 @@
-# $NetBSD: genassym.cf,v 1.31 2011/01/23 21:53:39 skrll Exp $
+# $NetBSD: genassym.cf,v 1.32 2011/02/01 18:33:24 skrll Exp $
# $OpenBSD: genassym.cf,v 1.18 2001/09/20 18:31:14 mickey Exp $
@@ -85,10 +85,10 @@
export HPPA_BREAK_SET_PSW
# hp700_int_reg fields
-struct hp700_int_reg
-member INT_REG_REQ int_reg_req
-member INT_REG_BITS_MAP int_reg_bits_map
-export INT_REG_BIT_REG
+struct hp700_interrupt_register
+member IR_REQ ir_req
+member IR_BITS_MAP ir_bits_map
+export IR_BIT_REG
# struct cpu_info fields
define CI_CPL offsetof(struct cpu_info, ci_cpl)
Index: src/sys/arch/hp700/hp700/intr.c
diff -u src/sys/arch/hp700/hp700/intr.c:1.33 src/sys/arch/hp700/hp700/intr.c:1.34
--- src/sys/arch/hp700/hp700/intr.c:1.33 Tue Feb 1 18:12:10 2011
+++ src/sys/arch/hp700/hp700/intr.c Tue Feb 1 18:33:24 2011
@@ -1,4 +1,4 @@
-/* $NetBSD: intr.c,v 1.33 2011/02/01 18:12:10 skrll Exp $ */
+/* $NetBSD: intr.c,v 1.34 2011/02/01 18:33:24 skrll Exp $ */
/* $OpenBSD: intr.c,v 1.27 2009/12/31 12:52:35 jsing Exp $ */
/*
@@ -35,7 +35,7 @@
*/
#include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: intr.c,v 1.33 2011/02/01 18:12:10 skrll Exp $");
+__KERNEL_RCSID(0, "$NetBSD: intr.c,v 1.34 2011/02/01 18:33:24 skrll Exp $");
#define __MUTEX_PRIVATE
@@ -66,21 +66,21 @@
int ishared;
/* The list of all interrupt registers. */
-struct hp700_int_reg *hp700_int_regs[HP700_INT_BITS];
+struct hp700_interrupt_register *hp700_interrupt_registers[HP700_INTERRUPT_BITS];
/*
* The array of interrupt handler structures, one per bit.
*/
-static struct hp700_int_bit {
+static struct hp700_interrupt_bit {
/* The interrupt register this bit is in. */
- struct hp700_int_reg *int_bit_reg;
+ struct hp700_interrupt_register *ib_reg;
/*
* The priority level associated with this bit, e.g, IPL_BIO, IPL_NET,
* etc.
*/
- int int_bit_ipl;
+ int ib_ipl;
/*
* The spl mask for this bit. This starts out as the spl bit assigned
@@ -88,46 +88,46 @@
* calculator to be the full mask that we need to raise spl to when we
* get this interrupt.
*/
- int int_bit_spl;
+ int ib_spl;
/* The interrupt name. */
- char int_bit_name[16];
+ char ib_name[16];
/* The interrupt event count. */
- struct evcnt int_bit_evcnt;
+ struct evcnt ib_evcnt;
/*
* The interrupt handler and argument for this bit. If the argument is
* NULL, the handler gets the trapframe.
*/
- int (*int_bit_handler)(void *);
- void *int_bit_arg;
+ int (*ib_handler)(void *);
+ void *ib_arg;
-} hp700_int_bits[HP700_INT_BITS];
+} hp700_interrupt_bits[HP700_INTERRUPT_BITS];
/* The CPU interrupt register. */
-struct hp700_int_reg int_reg_cpu;
+struct hp700_interrupt_register ir_cpu;
/*
* This establishes a new interrupt register.
*/
void
-hp700_intr_reg_establish(struct hp700_int_reg *int_reg)
+hp700_interrupt_register_establish(struct hp700_interrupt_register *ir)
{
int idx;
/* Initialize the register structure. */
- memset(int_reg, 0, sizeof(*int_reg));
- for (idx = 0; idx < HP700_INT_BITS; idx++)
- int_reg->int_reg_bits_map[idx] = INT_REG_BIT_UNUSED;
+ memset(ir, 0, sizeof(*ir));
+ for (idx = 0; idx < HP700_INTERRUPT_BITS; idx++)
+ ir->ir_bits_map[idx] = IR_BIT_UNUSED;
/* Add this structure to the list. */
- for (idx = 0; idx < HP700_INT_BITS; idx++)
- if (hp700_int_regs[idx] == NULL)
+ for (idx = 0; idx < HP700_INTERRUPT_BITS; idx++)
+ if (hp700_interrupt_registers[idx] == NULL)
break;
- if (idx == HP700_INT_BITS)
- panic("hp700_intr_reg_establish: too many regs");
- hp700_int_regs[idx] = int_reg;
+ if (idx == HP700_INTERRUPT_BITS)
+ panic("hp700_interrupt_register_establish: too many regs");
+ hp700_interrupt_registers[idx] = ir;
}
/*
@@ -153,14 +153,14 @@
ci->ci_intr_depth = 0;
/* There are no interrupt handlers. */
- memset(hp700_int_bits, 0, sizeof(hp700_int_bits));
+ memset(hp700_interrupt_bits, 0, sizeof(hp700_interrupt_bits));
/* There are no interrupt registers. */
- memset(hp700_int_regs, 0, sizeof(hp700_int_regs));
+ memset(hp700_interrupt_registers, 0, sizeof(hp700_interrupt_registers));
/* Initialize the CPU interrupt register description. */
- hp700_intr_reg_establish(&int_reg_cpu);
- int_reg_cpu.int_reg_name = "cpu0";
+ hp700_interrupt_register_establish(&ir_cpu);
+ ir_cpu.ir_name = "cpu0";
}
/*
@@ -168,21 +168,21 @@
*/
void *
hp700_intr_establish(int ipl, int (*handler)(void *), void *arg,
- struct hp700_int_reg *int_reg, int bit_pos)
+ struct hp700_interrupt_register *ir, int bit_pos)
{
- struct hp700_int_bit *int_bit;
+ struct hp700_interrupt_bit *ib;
int idx;
/* Panic on a bad interrupt bit. */
- if (bit_pos < 0 || bit_pos >= HP700_INT_BITS)
+ if (bit_pos < 0 || bit_pos >= HP700_INTERRUPT_BITS)
panic("%s: bad interrupt bit %d", __func__, bit_pos);
/*
- * Panic if this int bit is already handled, but allow shared
+ * Panic if this interrupt bit is already handled, but allow shared
* interrupts for PCI.
*/
- if (int_reg->int_reg_bits_map[31 ^ bit_pos] != INT_REG_BIT_UNUSED &&
- !INT_REG_BIT_NESTED_P(int_reg->int_reg_bits_map[31 ^ bit_pos]) &&
+ if (ir->ir_bits_map[31 ^ bit_pos] != IR_BIT_UNUSED &&
+ !IR_BIT_NESTED_P(ir->ir_bits_map[31 ^ bit_pos]) &&
handler == NULL)
panic("hp700_intr_establish: int already handled");
@@ -191,13 +191,13 @@
* simply note that in the mapping for the bit.
*/
if (handler == NULL) {
- for (idx = 0; idx < HP700_INT_BITS; idx++)
- if (hp700_int_regs[idx] == arg)
+ for (idx = 0; idx < HP700_INTERRUPT_BITS; idx++)
+ if (hp700_interrupt_registers[idx] == arg)
break;
- if (idx == HP700_INT_BITS)
+ if (idx == HP700_INTERRUPT_BITS)
panic("hp700_intr_establish: unknown int reg");
- int_reg->int_reg_bits_map[31 ^ bit_pos] =
- (INT_REG_BIT_REG | idx);
+ ir->ir_bits_map[31 ^ bit_pos] = IR_BIT_REG | idx;
+
return NULL;
}
@@ -205,28 +205,27 @@
* Otherwise, allocate a new bit in the spl.
*/
idx = _hp700_intr_ipl_next();
- int_reg->int_reg_allocatable_bits &= ~(1 << bit_pos);
- if (int_reg->int_reg_bits_map[31 ^ bit_pos] == INT_REG_BIT_UNUSED)
- int_reg->int_reg_bits_map[31 ^ bit_pos] = 1 << idx;
+ ir->ir_bits &= ~(1 << bit_pos);
+ if (ir->ir_bits_map[31 ^ bit_pos] == IR_BIT_UNUSED)
+ ir->ir_bits_map[31 ^ bit_pos] = 1 << idx;
else {
- int_reg->int_reg_bits_map[31 ^ bit_pos] |= 1 << idx;
- ishared |= int_reg->int_reg_bits_map[31 ^ bit_pos];
+ ir->ir_bits_map[31 ^ bit_pos] |= 1 << idx;
+ ishared |= ir->ir_bits_map[31 ^ bit_pos];
}
- int_bit = hp700_int_bits + idx;
+ ib = &hp700_interrupt_bits[idx];
- /* Fill this int bit. */
- int_bit->int_bit_reg = int_reg;
- int_bit->int_bit_ipl = ipl;
- int_bit->int_bit_spl = (1 << idx);
- snprintf(int_bit->int_bit_name, sizeof(int_bit->int_bit_name), "irq %d",
- bit_pos);
-
- evcnt_attach_dynamic(&int_bit->int_bit_evcnt, EVCNT_TYPE_INTR, NULL,
- int_reg->int_reg_name, int_bit->int_bit_name);
- int_bit->int_bit_handler = handler;
- int_bit->int_bit_arg = arg;
+ /* Fill this interrupt bit. */
+ ib->ib_reg = ir;
+ ib->ib_ipl = ipl;
+ ib->ib_spl = (1 << idx);
+ snprintf(ib->ib_name, sizeof(ib->ib_name), "irq %d", bit_pos);
+
+ evcnt_attach_dynamic(&ib->ib_evcnt, EVCNT_TYPE_INTR, NULL, ir->ir_name,
+ ib->ib_name);
+ ib->ib_handler = handler;
+ ib->ib_arg = arg;
- return int_bit;
+ return ib;
}
/*
@@ -234,17 +233,17 @@
* It returns the bit position, or -1 if no bits were available.
*/
int
-hp700_intr_allocate_bit(struct hp700_int_reg *int_reg)
+hp700_intr_allocate_bit(struct hp700_interrupt_register *int_reg)
{
int bit_pos, mask;
for (bit_pos = 31, mask = (1 << bit_pos);
bit_pos >= 0;
bit_pos--, mask >>= 1)
- if (int_reg->int_reg_allocatable_bits & mask)
+ if (int_reg->ir_bits & mask)
break;
if (bit_pos >= 0)
- int_reg->int_reg_allocatable_bits &= ~mask;
+ int_reg->ir_bits &= ~mask;
return bit_pos;
}
@@ -256,10 +255,10 @@
{
int idx;
- for (idx = 0; idx < HP700_INT_BITS; idx++)
- if (hp700_int_bits[idx].int_bit_reg == NULL)
+ for (idx = 0; idx < HP700_INTERRUPT_BITS; idx++)
+ if (hp700_interrupt_bits[idx].ib_reg == NULL)
break;
- if (idx == HP700_INT_BITS)
+ if (idx == HP700_INTERRUPT_BITS)
panic("_hp700_intr_spl_bit: too many devices");
return idx;
}
@@ -270,8 +269,8 @@
void
hp700_intr_init(void)
{
- struct hp700_int_bit *int_bit;
- struct hp700_int_reg *int_reg;
+ struct hp700_interrupt_bit *ib;
+ struct hp700_interrupt_register *ir;
struct cpu_info *ci = curcpu();
int idx, bit_pos;
int mask;
@@ -281,11 +280,11 @@
* Put together the initial imask for each level.
*/
memset(imask, 0, sizeof(imask));
- for (bit_pos = 0; bit_pos < HP700_INT_BITS; bit_pos++) {
- int_bit = hp700_int_bits + bit_pos;
- if (int_bit->int_bit_reg == NULL)
+ for (bit_pos = 0; bit_pos < HP700_INTERRUPT_BITS; bit_pos++) {
+ ib = hp700_interrupt_bits + bit_pos;
+ if (ib->ib_reg == NULL)
continue;
- imask[int_bit->int_bit_ipl] |= int_bit->int_bit_spl;
+ imask[ib->ib_ipl] |= ib->ib_spl;
}
/* The following bits cribbed from i386/isa/isa_machdep.c: */
@@ -309,11 +308,11 @@
imask[IPL_HIGH] |= imask[IPL_SCHED];
/* Now go back and flesh out the spl levels on each bit. */
- for (bit_pos = 0; bit_pos < HP700_INT_BITS; bit_pos++) {
- int_bit = hp700_int_bits + bit_pos;
- if (int_bit->int_bit_reg == NULL)
+ for (bit_pos = 0; bit_pos < HP700_INTERRUPT_BITS; bit_pos++) {
+ ib = hp700_interrupt_bits + bit_pos;
+ if (ib->ib_reg == NULL)
continue;
- int_bit->int_bit_spl = imask[int_bit->int_bit_ipl];
+ ib->ib_spl = imask[ib->ib_ipl];
}
/* Print out the levels. */
@@ -336,20 +335,20 @@
ci->ci_cpl = -1;
ci->ci_ipending = 0;
eiem = 0;
- for (idx = 0; idx < HP700_INT_BITS; idx++) {
- int_reg = hp700_int_regs[idx];
- if (int_reg == NULL)
+ for (idx = 0; idx < HP700_INTERRUPT_BITS; idx++) {
+ ir = hp700_interrupt_registers[idx];
+ if (ir == NULL)
continue;
mask = 0;
- for (bit_pos = 0; bit_pos < HP700_INT_BITS; bit_pos++) {
- if (int_reg->int_reg_bits_map[31 ^ bit_pos] !=
- INT_REG_BIT_UNUSED)
+ for (bit_pos = 0; bit_pos < HP700_INTERRUPT_BITS; bit_pos++) {
+ if (ir->ir_bits_map[31 ^ bit_pos] !=
+ IR_BIT_UNUSED)
mask |= (1 << bit_pos);
}
- if (int_reg == &int_reg_cpu)
+ if (ir == &ir_cpu)
eiem = mask;
- else if (int_reg->int_reg_mask != NULL)
- *int_reg->int_reg_mask = mask;
+ else if (ir->ir_mask != NULL)
+ *ir->ir_mask = mask;
}
mtctl(eiem, CR_EIEM);
}
@@ -366,8 +365,8 @@
int ipending_new;
int pending;
int i;
- struct hp700_int_reg *int_reg;
- int hp700_intr_ipending_new(struct hp700_int_reg *, int);
+ struct hp700_interrupt_register *ir;
+ int hp700_intr_ipending_new(struct hp700_interrupt_register *, int);
struct cpu_info *ci = curcpu();
#ifndef LOCKDEBUG
@@ -404,7 +403,7 @@
mfctl(CR_EIRR, eirr);
mtctl(eirr, CR_EIRR);
- ci->ci_ipending |= hp700_intr_ipending_new(&int_reg_cpu, eirr);
+ ci->ci_ipending |= hp700_intr_ipending_new(&ir_cpu, eirr);
/* If we have interrupts to dispatch, do so. */
if (ci->ci_ipending & ~ci->ci_cpl)
@@ -414,19 +413,19 @@
if (ishared == 0)
return;
- for (i = 0; i < HP700_INT_BITS; i++) {
- int_reg = hp700_int_regs[i];
- if (int_reg == NULL || int_reg->int_reg_level == NULL)
+ for (i = 0; i < HP700_INTERRUPT_BITS; i++) {
+ ir = hp700_interrupt_registers[i];
+ if (ir == NULL || ir->ir_level == NULL)
continue;
/*
* For shared interrupts look if the interrupt line is still
* asserted. If it is, reschedule the corresponding interrupt.
*/
- ipending_new = *int_reg->int_reg_level;
+ ipending_new = *ir->ir_level;
while (ipending_new != 0) {
pending = ffs(ipending_new) - 1;
ci->ci_ipending |=
- int_reg->int_reg_bits_map[31 ^ pending] & ishared;
+ ir->ir_bits_map[31 ^ pending] & ishared;
ipending_new &= ~(1 << pending);
}
}
@@ -447,7 +446,7 @@
int ipending_run;
u_int old_hppa_intr_depth;
int bit_pos;
- struct hp700_int_bit *int_bit;
+ struct hp700_interrupt_bit *ib;
void *arg;
struct clockframe clkframe;
int handled;
@@ -470,9 +469,9 @@
* If this interrupt handler takes the clockframe
* as an argument, conjure one up.
*/
- int_bit = hp700_int_bits + bit_pos;
- int_bit->int_bit_evcnt.ev_count++;
- arg = int_bit->int_bit_arg;
+ ib = &hp700_interrupt_bits[bit_pos];
+ ib->ib_evcnt.ev_count++;
+ arg = ib->ib_arg;
if (arg == NULL) {
clkframe.cf_flags = (old_hppa_intr_depth ?
TFF_INTR : 0);
@@ -490,16 +489,16 @@
* and reenable interrupts.
*/
ci->ci_ipending &= ~(1 << bit_pos);
- ci->ci_cpl = ncpl | int_bit->int_bit_spl;
+ ci->ci_cpl = ncpl | ib->ib_spl;
mtctl(eiem, CR_EIEM);
/* Count and dispatch the interrupt. */
ci->ci_data.cpu_nintr++;
- handled = (*int_bit->int_bit_handler)(arg);
+ handled = (*ib->ib_handler)(arg);
#if 0
if (!handled)
printf("%s: can't handle interrupt\n",
- int_bit->int_bit_evcnt.ev_name);
+ ib->ib_evcnt.ev_name);
#endif
/* Disable interrupts and loop. */
Index: src/sys/arch/hp700/hp700/intr.h
diff -u src/sys/arch/hp700/hp700/intr.h:1.14 src/sys/arch/hp700/hp700/intr.h:1.15
--- src/sys/arch/hp700/hp700/intr.h:1.14 Thu Jan 20 19:43:16 2011
+++ src/sys/arch/hp700/hp700/intr.h Tue Feb 1 18:33:25 2011
@@ -1,4 +1,4 @@
-/* $NetBSD: intr.h,v 1.14 2011/01/20 19:43:16 skrll Exp $ */
+/* $NetBSD: intr.h,v 1.15 2011/02/01 18:33:25 skrll Exp $ */
/*-
* Copyright (c) 2002 The NetBSD Foundation, Inc.
@@ -30,38 +30,38 @@
*/
/*
- * The maximum number of bits in a cpl value/spl mask,
- * the maximum number of bits in an interrupt request register,
- * and the maximum number of interrupt registers.
+ * The maximum number of bits in a cpl value/spl mask, the maximum number of
+ * bits in an interrupt request register, and the maximum number of interrupt
+ * registers.
*/
-#define HP700_INT_BITS (32)
-#define CPU_NINTS HP700_INT_BITS /* Use this one */
+#define HP700_INTERRUPT_BITS (32)
+#define CPU_NINTS HP700_INTERRUPT_BITS /* Use this one */
/*
* This describes one HP700 interrupt register.
*/
-struct hp700_int_reg {
+struct hp700_interrupt_register {
/*
* The device name for this interrupt register.
*/
- const char *int_reg_name;
+ const char *ir_name;
/*
* The virtual address of the mask, request and level
* registers.
*/
- volatile int *int_reg_mask;
- volatile int *int_reg_req;
- volatile int *int_reg_level;
+ volatile int *ir_mask;
+ volatile int *ir_req;
+ volatile int *ir_level;
/*
* This array has one entry for each bit in the interrupt request
* register.
*
* If the 24 most significant bits are set, the low 8 bits are the
* index of the hp700_int_reg that this interrupt bit leads to, with
* zero meaning that the interrupt bit is unused.
*
* Otherwise these bits correspond to hp700_int_bits. That is, these
* bits are ORed to ipending_new in hp700_intr_ipending_new() when an
@@ -71,23 +71,26 @@
* bit number. In other words, the least significant bit in the inter-
* rupt register corresponds to array index 31.
*/
- unsigned int int_reg_bits_map[HP700_INT_BITS];
-#define INT_REG_BIT_REG 0xffffff00
-#define INT_REG_BIT_UNUSED INT_REG_BIT_REG
-#define INT_REG_BIT_NESTED_P(x) (((x) & ~INT_REG_BIT_UNUSED) != 0)
+
+ unsigned int ir_bits_map[HP700_INTERRUPT_BITS];
+
+#define IR_BIT_REG 0xffffff00
+#define IR_BIT_UNUSED IR_BIT_REG
+#define IR_BIT_NESTED_P(x) (((x) & ~IR_BIT_UNUSED) != 0)
/*
* The mask of allocatable bit numbers.
*/
- int int_reg_allocatable_bits;
+ int ir_bits;
};
-extern struct hp700_int_reg int_reg_cpu;
+extern struct hp700_interrupt_register ir_cpu;
+
void hp700_intr_bootstrap(void);
-void hp700_intr_reg_establish(struct hp700_int_reg *);
-void * hp700_intr_establish(int, int (*)(void *), void *,
- struct hp700_int_reg *, int);
-int hp700_intr_allocate_bit(struct hp700_int_reg *);
+void hp700_interrupt_register_establish(struct hp700_interrupt_register *);
+void * hp700_intr_establish(int, int (*)(void *), void *,
+ struct hp700_interrupt_register *, int);
+int hp700_intr_allocate_bit(struct hp700_interrupt_register *);
int _hp700_intr_ipl_next(void);
void hp700_intr_init(void);
void hp700_intr_dispatch(int, int, struct trapframe *);
@@ -30,38 +30,38 @@
* register.
*
- * If the 24 most significant bits are set, the low 8 bits are the
- * index of the hp700_int_reg that this interrupt bit leads to, with
- * zero meaning that the interrupt bit is unused.
+ * If the 24 most significant bits are set, the low 8 bits are the
+ * index of the hp700_interrupt_register that this interrupt bit leads
+ * to, with zero meaning that the interrupt bit is unused.
*
* Otherwise these bits correspond to hp700_int_bits. That is, these
Index: src/sys/arch/hp700/hp700/locore.S
diff -u src/sys/arch/hp700/hp700/locore.S:1.53 src/sys/arch/hp700/hp700/locore.S:1.54
--- src/sys/arch/hp700/hp700/locore.S:1.53 Sun Jan 23 21:53:39 2011
+++ src/sys/arch/hp700/hp700/locore.S Tue Feb 1 18:33:25 2011
@@ -1,4 +1,4 @@
-/* $NetBSD: locore.S,v 1.53 2011/01/23 21:53:39 skrll Exp $ */
+/* $NetBSD: locore.S,v 1.54 2011/02/01 18:33:25 skrll Exp $ */
/* $OpenBSD: locore.S,v 1.158 2008/07/28 19:08:46 miod Exp $ */
/*
@@ -152,7 +152,7 @@
.import lwp0, data
.import panic, code
.import fpu_csw, data
- .import hp700_int_regs, data
+ .import hp700_interrupt_registers, data
BSS(pdc_stack, 4) /* temp stack for PDC call */
BSS(kernelmapped, 4) /* set when kernel is mapped */
@@ -780,7 +780,7 @@
* and start with the least significant bit and with
* a zero ipending_new value.
*/
- ldo INT_REG_BITS_MAP(%arg0), %arg0
+ ldo IR_BITS_MAP(%arg0), %arg0
ldi 31, %arg2
copy %r0, %ret0
@@ -798,14 +798,14 @@
addib,<,n -1, %arg2, L$hp700_inew_done
/*
* If the map entry for this bit has INT_REG_BIT_REG
* set, branch to descend into the next interrupt
* register. Otherwise, set the bits in our ipending_new
* value and loop.
*/
ldwx,s %arg2(%arg0), %t1
- ldil L%INT_REG_BIT_REG, %t2
- ldo R%INT_REG_BIT_REG(%t2), %t2
+ ldil L%IR_BIT_REG, %t2
+ ldo R%IR_BIT_REG(%t2), %t2
and %t1, %t2, %t3
combt,=,n %t2, %t3, L$hp700_inew_descend
addib,>= -1, %arg2, L$hp700_inew_loop
@@ -837,8 +837,8 @@
stw %ret0, HPPA_FRAME_ARG(3)(%r3)
/* Get our new interrupt register. */
- ldil L%hp700_int_regs, %arg0
- ldo R%hp700_int_regs(%arg0), %arg0
+ ldil L%hp700_interrupt_registers, %arg0
+ ldo R%hp700_interrupt_registers(%arg0), %arg0
sh2add %t1, %arg0, %arg0
ldw 0(%arg0), %arg0
@@ -847,7 +847,7 @@
* our recursive call. The read also serves to
* acknowledge the interrupt to the I/O subsystem.
*/
- ldw INT_REG_REQ(%arg0), %arg1
+ ldw IR_REQ(%arg0), %arg1
bl hp700_intr_ipending_new, %rp
ldw 0(%arg1), %arg1
@@ -798,14 +798,14 @@
addib,<,n -1, %arg2, L$hp700_inew_done
/*
- * If the map entry for this bit has INT_REG_BIT_REG
+ * If the map entry for this bit has IR_BIT_REG
* set, branch to descend into the next interrupt
* register. Otherwise, set the bits in our ipending_new